@@ -3,6 +3,7 @@ from .index_key import IndexKey
 from .index_primary import IndexPrimary
 from .index_unique import IndexUnique
 from .type_character import TypeCharacter
+from .type_datetime import TypeDateTime
 from .type_decimal import TypeDecimal
 from .type_enum import TypeEnum
 from .type_numeric import TypeNumeric
@@ -12,6 +13,6 @@ from .table_option import TableOption
 from .insert_values import InsertValues
 
 __all__ = [
-    "ConstraintForeign", "IndexKey", "IndexPrimary", "IndexUnique", "TypeCharacter", "TypeDecimal", "TypeEnum",
-    "TypeNumeric", "TypePlain", "TypeText", "TableOption", "InsertValues"
+    "ConstraintForeign", "IndexKey", "IndexPrimary", "IndexUnique", "TypeCharacter", "TypeDecimal", "TypeDateTime",
+    "TypeEnum", "TypeNumeric", "TypePlain", "TypeText", "TableOption", "InsertValues"
 ]
